# 25 "src/kernel_internals/parsing/logic_lexer.mll"
 

  open Logic_parser
  open Lexing
  open Logic_ptree

  type state = Normal | Test

  let state_stack = Stack.create ()

  let () = Stack.push Normal state_stack

  let get_state () = try Stack.top state_stack with Stack.Empty -> Normal

  let pop_state () = try ignore (Stack.pop state_stack) with Stack.Empty -> ()

  exception Error of (int * int) * string

  let loc lexbuf = (lexeme_start lexbuf, lexeme_end lexbuf)

  let lex_error lexbuf s =
    raise (Error (loc lexbuf, "lexical error, " ^ s))

  let find_utf8 =
    let h = Hashtbl.create 97 in
    List.iter (fun (i,t) -> Hashtbl.add h i t)
      [ Utf8_logic.forall, FORALL;
        Utf8_logic.exists, EXISTS;
        Utf8_logic.eq, EQ;
        Utf8_logic.neq, NE;
        Utf8_logic.le, LE;
        Utf8_logic.ge, GE;
        Utf8_logic.implies,IMPLIES;
        Utf8_logic.iff, IFF;
        Utf8_logic.conj, AND;
        Utf8_logic.disj, OR;
        Utf8_logic.neg, NOT;
        Utf8_logic.x_or, HATHAT;
        Utf8_logic.minus, MINUS;
        Utf8_logic.boolean, BOOLEAN;
        Utf8_logic.integer, INTEGER;
        Utf8_logic.real, REAL
      ];

    fun s -> try Hashtbl.find h s
    with Not_found -> IDENTIFIER s

  let identifier, is_acsl_keyword =
    let all_kw = Hashtbl.create 37 in
    let c_kw = Hashtbl.create 37 in
    let type_kw = Hashtbl.create 3 in
    List.iter
      (fun (i,t,flag) ->
         Hashtbl.add all_kw i t;
         if flag then Hashtbl.add c_kw i t
      )
      [
        "allocates", ALLOCATES, false;
        "assert", ASSERT, false;
        "assigns", ASSIGNS, false;
        "assumes", ASSUMES, false;
        "at", EXT_AT, false;(* ACSL extension for external spec file *)
        "axiom", AXIOM, false;
        "axiomatic", AXIOMATIC, false;
        "behavior", BEHAVIOR, false;
        "behaviors", BEHAVIORS, false;
        "_Bool", BOOL, true;
        "breaks", BREAKS, false;
	"case", CASE, true;
        "char", CHAR, true;
        "complete", COMPLETE, false;
        "const", CONST, true;
        "continues", CONTINUES, false;
        "contract", CONTRACT, false;(* ACSL extension for external spec file *)
	"custom", CUSTOM, false; (* ACSL extension for custom annotations *)
        "decreases", DECREASES, false;
        "disjoint", DISJOINT, false;
        "double", DOUBLE, true;
        "else", ELSE, true;
        "ensures", ENSURES, false ;
        "enum", ENUM, true;
        "exits", EXITS, false;
        "frees", FREES, false;
        "function", FUNCTION, false;(* ACSL extension for external spec file *)
        "float", FLOAT, true;
        "for", FOR, true;
        "global",    GLOBAL, false;
        "if", IF, true;
	"impact", IMPACT, false;
	"inductive", INDUCTIVE, false;
	"include", INCLUDE, false;(* ACSL extension for external spec file *)
        "int", INT, true;
        "invariant", INVARIANT, false;
        "label", LABEL, false;
        "lemma", LEMMA, false;
        "let", EXT_LET, false;(* ACSL extension for external spec file *)
        "logic", LOGIC, false;
        "long", LONG, true;
        "loop", LOOP, false;
        "model", MODEL, false;(* ACSL extension for model fields *)
        "module", MODULE, false;(* ACSL extension for external spec file *)
        "pragma", PRAGMA, false;
        "predicate", PREDICATE, false;
        "reads", READS, false;
        "requires", REQUIRES, false;
        "returns", RETURNS, false;
        "short", SHORT, true;
        "signed", SIGNED, true;
        "sizeof", SIZEOF, true;
        "slice", SLICE, false;
        "struct", STRUCT, true;
        "terminates", TERMINATES, false;
        "type", TYPE, false;
        "union", UNION, true;
        "unsigned", UNSIGNED, true;
        "variant", VARIANT, false;
        "void", VOID, true;
        "volatile", VOLATILE, true;
        "writes", WRITES, false;
      ];
    List.iter (fun (x, y) -> Hashtbl.add type_kw x y)
      ["integer", INTEGER; "real", REAL; "boolean", BOOLEAN; ];
    (fun s ->
      try
        Hashtbl.find (if Logic_utils.is_kw_c_mode () then c_kw else all_kw) s
      with Not_found ->
        if Logic_env.typename_status s then TYPENAME s
        else
          (try
             Hashtbl.find type_kw s
           with Not_found ->
             if Logic_utils.is_rt_type_mode () then TYPENAME s
             else IDENTIFIER s)),
    (fun s -> Hashtbl.mem all_kw s || Hashtbl.mem type_kw s)

  let bs_identifier =
    let h = Hashtbl.create 97 in
    List.iter (fun (i,t) -> Hashtbl.add h i t)
      [
        "\\allocation", ALLOCATION;
        "\\allocable", ALLOCABLE;
        "\\automatic", AUTOMATIC;
        "\\at", AT;
        "\\base_addr", BASE_ADDR;
        "\\block_length", BLOCK_LENGTH;
        "\\dynamic", DYNAMIC;
        "\\empty", EMPTY;
        "\\exists", EXISTS;
        "\\false", FALSE;
        "\\forall", FORALL;
        "\\freeable", FREEABLE;
        "\\fresh", FRESH;
        "\\from", FROM;
        "\\initialized", INITIALIZED;
        "\\dangling", DANGLING;
        "\\inter", INTER;
        "\\lambda", LAMBDA;
        "\\let", LET;
        "\\nothing", NOTHING;
        "\\null", NULL;
        "\\offset", OFFSET;
        "\\old", OLD;
        "\\register", REGISTER;
        "\\result", RESULT;
        "\\separated", SEPARATED;
        "\\static", STATIC;
        "\\true", TRUE;
        "\\type", BSTYPE;
        "\\typeof", TYPEOF;
        "\\unallocated", UNALLOCATED;
        "\\union", BSUNION;
        "\\valid", VALID;
        "\\valid_read", VALID_READ;
        "\\valid_index", VALID_INDEX;
        "\\valid_range", VALID_RANGE;
        "\\with", WITH;
      ];
    fun lexbuf ->
      let s = lexeme lexbuf in
      try Hashtbl.find h s with Not_found -> IDENTIFIER s


  let int_of_digit chr =
    match chr with
        '0'..'9' -> (Char.code chr) - (Char.code '0')
      | 'a'..'f' -> (Char.code chr) - (Char.code 'a') + 10
      | 'A'..'F' -> (Char.code chr) - (Char.code 'A') + 10
      | _ -> assert false

  (* Update lexer buffer. *)
  let update_newline_loc lexbuf =
    let pos = lexbuf.Lexing.lex_curr_p in
    lexbuf.Lexing.lex_curr_p <-
      { pos with
	Lexing.pos_lnum = pos.Lexing.pos_lnum + 1;
	Lexing.pos_bol = pos.Lexing.pos_cnum;
      }

  (* Update lexer buffer. *)
  let update_line_loc lexbuf line absolute chars =
    let pos = lexbuf.Lexing.lex_curr_p in
    lexbuf.Lexing.lex_curr_p <-
      { pos with
	Lexing.pos_lnum =
          if absolute then line else pos.Lexing.pos_lnum + line;
	Lexing.pos_bol = pos.Lexing.pos_cnum - chars;
      }

  (* Update lexer buffer. *)
  let update_file_loc lexbuf file =
   let pos = lexbuf.Lexing.lex_curr_p in
    lexbuf.Lexing.lex_curr_p <- { pos with Lexing.pos_fname = file }

  (* Update lexer buffer. *)
  let update_bol_loc lexbuf bol =
    let pos = lexbuf.Lexing.lex_curr_p in
    lexbuf.Lexing.lex_curr_p <- { pos with Lexing.pos_bol = bol}

# 221 "src/kernel_internals/parsing/logic_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\193\255\194\255\000\000\200\255\201\255\202\255\203\255\
    \204\255\205\255\196\000\213\255\215\255\165\000\220\255\221\255\
    \202\000\228\255\229\255\231\255\232\255\200\000\138\000\225\000\
    \220\000\223\000\205\000\240\255\001\001\223\000\004\001\252\000\
    \034\001\107\001\196\001\254\001\238\000\254\255\028\001\089\001\
    \252\255\253\255\073\002\186\002\125\002\091\001\126\002\244\255\
    \241\255\092\001\153\002\182\002\210\000\194\002\239\000\008\003\
    \031\003\090\003\232\002\160\003\246\000\128\003\198\003\231\003\
    \007\004\063\003\243\255\017\004\046\004\078\004\088\004\107\004\
    \140\004\172\004\182\004\029\001\030\001\032\001\201\004\211\004\
    \242\255\233\004\243\004\016\005\026\005\055\005\065\005\094\005\
    \243\000\106\005\135\005\145\005\174\005\223\255\228\000\239\255\
    \197\255\199\255\247\000\233\000\248\000\238\255\249\000\236\255\
    \230\255\250\000\237\255\235\255\234\255\206\255\198\255\226\255\
    \218\255\196\255\209\255\231\000\251\255\252\255\207\005\253\255\
    \075\001\024\006\047\006\188\001\254\255\233\005\251\255\208\000\
    \223\005\254\255\255\255\204\000\214\000\252\255\034\003\252\255\
    \132\001\254\255\255\255\253\255\000\003\133\001\253\255\254\255\
    \255\255";
  Lexing.lex_backtrk = 
   "\255\255\255\255\255\255\060\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\044\000\255\255\255\255\038\000\255\255\255\255\
    \028\000\255\255\255\255\255\255\255\255\022\000\039\000\036\000\
    \033\000\043\000\048\000\255\255\062\000\030\000\062\000\009\000\
    \009\000\005\000\005\000\062\000\041\000\255\255\000\000\255\255\
    \255\255\255\255\004\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\012\000\255\255\010\000\008\000\255\255\255\255\
    \255\255\006\000\255\255\255\255\006\000\255\255\255\255\255\255\
    \012\000\255\255\255\255\012\000\255\255\012\000\255\255\255\255\
    \255\255\012\000\255\255\007\000\007\000\008\000\012\000\255\255\
    \255\255\255\255\012\000\255\255\012\000\255\255\012\000\255\255\
    \031\000\012\000\255\255\012\000\255\255\255\255\047\000\255\255\
    \255\255\255\255\255\255\045\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\004\000\255\255\
    \001\000\255\255\000\000\001\000\255\255\255\255\255\255\004\000\
    \002\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \003\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255";
  Lexing.lex_default = 
   "\003\000\000\000\000\000\255\255\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\000\000\000\000\255\255\000\000\000\000\
    \255\255\000\000\000\000\000\000\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\043\000\255\255\046\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\039\000\
    \000\000\000\000\255\255\043\000\046\000\046\000\046\000\000\000\
    \000\000\043\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\000\000\
    \000\000\000\000\255\255\255\255\255\255\000\000\255\255\000\000\
    \000\000\255\255\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\116\000\000\000\000\000\255\255\000\000\
    \255\255\255\255\255\255\255\255\000\000\126\000\000\000\255\255\
    \255\255\000\000\000\000\255\255\255\255\000\000\135\000\000\000\
    \140\000\000\000\000\000\000\000\140\000\142\000\000\000\000\000\
    \000\000";
  Lexing.lex_trans = 
   "\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\038\000\037\000\001\000\038\000\038\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \038\000\021\000\028\000\027\000\020\000\011\000\023\000\030\000\
    \009\000\008\000\014\000\015\000\019\000\024\000\029\000\036\000\
    \032\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\016\000\017\000\025\000\026\000\010\000\018\000\
    \038\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\034\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\005\000\035\000\004\000\013\000\033\000\
    \001\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\007\000\022\000\006\000\012\000\001\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\001\000\
    \002\000\114\000\113\000\112\000\111\000\109\000\108\000\107\000\
    \110\000\105\000\094\000\255\255\098\000\088\000\255\255\089\000\
    \089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\097\000\104\000\096\000\099\000\039\000\052\000\075\000\
    \075\000\093\000\095\000\048\000\102\000\038\000\100\000\052\000\
    \038\000\038\000\050\000\255\255\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\101\000\103\000\
    \106\000\131\000\132\000\133\000\038\000\000\000\052\000\000\000\
    \000\000\051\000\060\000\118\000\000\000\000\000\000\000\052\000\
    \052\000\000\000\000\000\060\000\000\000\075\000\075\000\000\000\
    \050\000\052\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\038\000\049\000\000\000\000\000\
    \045\000\051\000\060\000\041\000\054\000\255\255\255\255\051\000\
    \052\000\076\000\076\000\060\000\077\000\000\000\052\000\000\000\
    \000\000\052\000\076\000\076\000\000\000\077\000\000\000\052\000\
    \000\000\000\000\055\000\123\000\123\000\123\000\123\000\123\000\
    \123\000\123\000\123\000\000\000\054\000\000\000\000\000\051\000\
    \000\000\076\000\076\000\000\000\077\000\255\255\052\000\144\000\
    \255\255\000\000\076\000\076\000\000\000\077\000\000\000\052\000\
    \000\000\000\000\055\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\000\000\139\000\000\000\
    \000\000\000\000\000\000\000\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\000\000\000\000\
    \000\000\000\000\033\000\000\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\043\000\117\000\
    \000\000\000\000\000\000\044\000\124\000\124\000\124\000\124\000\
    \124\000\124\000\124\000\124\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\000\000\000\000\
    \000\000\255\255\000\000\000\000\255\255\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\000\000\
    \000\000\000\000\000\000\033\000\000\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\040\000\000\000\255\255\255\255\042\000\000\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\000\000\255\255\143\000\000\000\255\255\
    \255\255\000\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\255\255\047\000\000\000\000\000\
    \042\000\000\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\255\255\000\000\000\000\080\000\
    \000\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\045\000\045\000\000\000\048\000\066\000\081\000\066\000\
    \000\000\079\000\000\000\079\000\000\000\066\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \050\000\000\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\000\000\066\000\081\000\066\000\
    \000\000\000\000\000\000\000\000\000\000\066\000\000\000\051\000\
    \000\000\255\255\000\000\000\000\255\255\000\000\077\000\000\000\
    \000\000\000\000\000\000\070\000\000\000\070\000\049\000\077\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\139\000\000\000\000\000\000\000\000\000\051\000\
    \000\000\000\000\000\000\137\000\138\000\000\000\077\000\137\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\056\000\077\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\137\000\000\000\136\000\000\000\000\000\000\000\
    \000\000\057\000\057\000\057\000\057\000\057\000\057\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\000\000\000\000\
    \000\000\057\000\057\000\057\000\057\000\057\000\057\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\000\000\000\000\000\000\000\000\255\255\255\255\000\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\000\000\000\000\
    \059\000\000\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\000\000\000\000\000\000\000\000\000\000\060\000\000\000\
    \000\000\000\000\058\000\068\000\000\000\068\000\000\000\060\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\255\255\057\000\057\000\057\000\057\000\057\000\
    \057\000\000\000\000\000\000\000\000\000\000\000\060\000\000\000\
    \000\000\000\000\058\000\000\000\000\000\000\000\000\000\060\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\062\000\062\000\062\000\062\000\062\000\062\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \061\000\000\000\000\000\000\000\000\000\000\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \255\255\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\000\000\000\000\000\000\
    \061\000\000\000\065\000\000\000\065\000\000\000\063\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\000\000\255\255\000\000\000\000\000\000\000\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\063\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\066\000\000\000\066\000\000\000\000\000\
    \000\000\000\000\000\000\066\000\000\000\066\000\000\000\066\000\
    \000\000\000\000\000\000\000\000\000\000\066\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \000\000\000\000\000\000\066\000\000\000\066\000\000\000\000\000\
    \000\000\000\000\000\000\066\000\000\000\066\000\000\000\066\000\
    \000\000\000\000\000\000\000\000\000\000\066\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\066\000\000\000\066\000\000\000\000\000\000\000\
    \000\000\000\000\066\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\066\000\000\000\066\000\000\000\000\000\074\000\
    \000\000\074\000\066\000\072\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\072\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\073\000\073\000\
    \066\000\000\000\066\000\000\000\000\000\000\000\000\000\000\000\
    \066\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\066\000\000\000\066\000\
    \066\000\000\000\066\000\000\000\087\000\066\000\087\000\000\000\
    \066\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\066\000\000\000\066\000\
    \000\000\000\000\000\000\000\000\000\000\066\000\000\000\066\000\
    \083\000\066\000\000\000\085\000\000\000\085\000\000\000\066\000\
    \084\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\000\000\000\000\000\000\066\000\
    \083\000\066\000\000\000\000\000\000\000\000\000\066\000\066\000\
    \066\000\000\000\000\000\000\000\000\000\000\000\066\000\084\000\
    \084\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\000\000\000\000\000\000\066\000\000\000\
    \066\000\000\000\000\000\000\000\000\000\066\000\066\000\066\000\
    \000\000\000\000\000\000\000\000\000\000\066\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \000\000\000\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\089\000\000\000\066\000\000\000\066\000\
    \000\000\000\000\000\000\000\000\000\000\066\000\066\000\090\000\
    \066\000\000\000\092\000\000\000\092\000\000\000\066\000\091\000\
    \091\000\091\000\091\000\091\000\091\000\091\000\091\000\091\000\
    \091\000\091\000\091\000\091\000\091\000\091\000\091\000\091\000\
    \091\000\091\000\091\000\000\000\000\000\000\000\066\000\090\000\
    \066\000\000\000\000\000\000\000\000\000\066\000\066\000\066\000\
    \000\000\000\000\000\000\000\000\000\000\066\000\091\000\091\000\
    \091\000\091\000\091\000\091\000\091\000\091\000\091\000\091\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\119\000\129\000\130\000\000\000\066\000\119\000\066\000\
    \000\000\000\000\000\000\000\000\000\000\066\000\000\000\120\000\
    \120\000\120\000\120\000\120\000\120\000\120\000\120\000\000\000\
    \000\000\129\000\000\000\000\000\000\000\000\000\119\000\128\000\
    \128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\
    \128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\
    \128\000\128\000\128\000\000\000\000\000\000\000\000\000\121\000\
    \000\000\000\000\000\000\119\000\000\000\000\000\000\000\000\000\
    \119\000\119\000\000\000\000\000\000\000\119\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\119\000\000\000\000\000\
    \000\000\119\000\000\000\119\000\000\000\119\000\000\000\121\000\
    \122\000\122\000\122\000\122\000\122\000\122\000\122\000\122\000\
    \122\000\122\000\000\000\000\000\000\000\127\000\000\000\000\000\
    \000\000\122\000\122\000\122\000\122\000\122\000\122\000\122\000\
    \122\000\122\000\122\000\122\000\122\000\122\000\122\000\122\000\
    \122\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \122\000\122\000\122\000\122\000\122\000\122\000\000\000\000\000\
    \000\000\122\000\122\000\122\000\122\000\122\000\122\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \122\000\122\000\122\000\122\000\122\000\122\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    ";
  Lexing.lex_check = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\000\000\
    \000\000\010\000\010\000\013\000\016\000\021\000\022\000\023\000\
    \016\000\024\000\026\000\028\000\025\000\029\000\030\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\025\000\024\000\025\000\025\000\036\000\052\000\054\000\
    \054\000\088\000\094\000\028\000\098\000\038\000\099\000\052\000\
    \038\000\038\000\031\000\030\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\100\000\102\000\
    \105\000\127\000\131\000\132\000\038\000\255\255\052\000\255\255\
    \255\255\031\000\060\000\115\000\255\255\255\255\255\255\052\000\
    \031\000\255\255\255\255\060\000\255\255\075\000\075\000\255\255\
    \032\000\031\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\038\000\028\000\255\255\255\255\
    \030\000\031\000\060\000\039\000\032\000\045\000\049\000\032\000\
    \031\000\075\000\076\000\060\000\077\000\255\255\032\000\255\255\
    \255\255\031\000\075\000\076\000\255\255\077\000\255\255\032\000\
    \255\255\255\255\032\000\120\000\120\000\120\000\120\000\120\000\
    \120\000\120\000\120\000\255\255\032\000\255\255\255\255\032\000\
    \255\255\075\000\076\000\255\255\077\000\136\000\032\000\141\000\
    \136\000\255\255\075\000\076\000\255\255\077\000\255\255\032\000\
    \255\255\255\255\032\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\255\255\136\000\255\255\
    \255\255\255\255\255\255\255\255\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\255\255\255\255\
    \255\255\255\255\033\000\255\255\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\034\000\115\000\
    \255\255\255\255\255\255\034\000\123\000\123\000\123\000\123\000\
    \123\000\123\000\123\000\123\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\255\255\255\255\
    \255\255\028\000\255\255\255\255\030\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\255\255\
    \255\255\255\255\255\255\034\000\255\255\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\039\000\255\255\045\000\049\000\035\000\255\255\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\255\255\136\000\141\000\255\255\044\000\
    \046\000\255\255\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\044\000\046\000\255\255\255\255\
    \042\000\255\255\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\043\000\255\255\255\255\050\000\
    \255\255\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\044\000\046\000\255\255\043\000\050\000\050\000\050\000\
    \255\255\051\000\255\255\051\000\255\255\050\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \053\000\255\255\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\255\255\050\000\050\000\050\000\
    \255\255\255\255\255\255\255\255\255\255\050\000\255\255\053\000\
    \255\255\140\000\255\255\255\255\140\000\255\255\053\000\255\255\
    \255\255\255\255\255\255\058\000\255\255\058\000\043\000\053\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\140\000\255\255\255\255\255\255\255\255\053\000\
    \255\255\255\255\255\255\134\000\134\000\255\255\053\000\134\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\055\000\053\000\
    \055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\134\000\255\255\134\000\255\255\255\255\255\255\
    \255\255\055\000\055\000\055\000\055\000\055\000\055\000\056\000\
    \056\000\056\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \056\000\056\000\056\000\056\000\056\000\056\000\255\255\255\255\
    \255\255\055\000\055\000\055\000\055\000\055\000\055\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\255\255\255\255\255\255\255\255\044\000\046\000\255\255\
    \056\000\056\000\056\000\056\000\056\000\056\000\255\255\255\255\
    \057\000\255\255\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\057\000\057\000\057\000\057\000\057\000\
    \057\000\255\255\255\255\255\255\255\255\255\255\057\000\255\255\
    \255\255\255\255\057\000\061\000\255\255\061\000\255\255\057\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\043\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\255\255\255\255\255\255\255\255\255\255\057\000\255\255\
    \255\255\255\255\057\000\255\255\255\255\255\255\255\255\057\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
    \059\000\059\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\059\000\059\000\059\000\059\000\059\000\059\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \059\000\255\255\255\255\255\255\255\255\255\255\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \140\000\059\000\059\000\059\000\059\000\059\000\059\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\255\255\255\255\255\255\
    \059\000\255\255\063\000\255\255\063\000\255\255\062\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\255\255\134\000\255\255\255\255\255\255\255\255\062\000\
    \062\000\062\000\062\000\062\000\062\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\062\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\064\000\255\255\064\000\255\255\255\255\
    \255\255\255\255\255\255\064\000\255\255\067\000\255\255\067\000\
    \255\255\255\255\255\255\255\255\255\255\067\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\068\000\
    \255\255\255\255\255\255\064\000\255\255\064\000\255\255\255\255\
    \255\255\255\255\255\255\064\000\255\255\067\000\255\255\067\000\
    \255\255\255\255\255\255\255\255\255\255\067\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\069\000\255\255\069\000\255\255\255\255\255\255\
    \255\255\255\255\069\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\071\000\071\000\071\000\071\000\
    \071\000\071\000\069\000\255\255\069\000\255\255\255\255\072\000\
    \255\255\072\000\069\000\071\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\071\000\071\000\071\000\071\000\
    \071\000\071\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\071\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \073\000\255\255\073\000\255\255\255\255\255\255\255\255\255\255\
    \073\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\078\000\255\255\078\000\
    \073\000\255\255\073\000\255\255\081\000\078\000\081\000\255\255\
    \073\000\081\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\078\000\255\255\078\000\
    \255\255\255\255\255\255\255\255\255\255\078\000\255\255\082\000\
    \082\000\082\000\255\255\083\000\255\255\083\000\255\255\082\000\
    \083\000\083\000\083\000\083\000\083\000\083\000\083\000\083\000\
    \083\000\083\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\084\000\084\000\255\255\255\255\255\255\082\000\
    \082\000\082\000\255\255\255\255\255\255\255\255\084\000\082\000\
    \084\000\255\255\255\255\255\255\255\255\255\255\084\000\085\000\
    \085\000\085\000\085\000\085\000\085\000\085\000\085\000\085\000\
    \085\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\255\255\255\255\255\255\084\000\255\255\
    \084\000\255\255\255\255\255\255\255\255\086\000\084\000\086\000\
    \255\255\255\255\255\255\255\255\255\255\086\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \255\255\255\255\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\089\000\255\255\086\000\255\255\086\000\
    \255\255\255\255\255\255\255\255\255\255\086\000\089\000\089\000\
    \089\000\255\255\090\000\255\255\090\000\255\255\089\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\091\000\091\000\091\000\091\000\091\000\091\000\091\000\
    \091\000\091\000\091\000\255\255\255\255\255\255\089\000\089\000\
    \089\000\255\255\255\255\255\255\255\255\091\000\089\000\091\000\
    \255\255\255\255\255\255\255\255\255\255\091\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\118\000\125\000\125\000\255\255\091\000\118\000\091\000\
    \255\255\255\255\255\255\255\255\255\255\091\000\255\255\118\000\
    \118\000\118\000\118\000\118\000\118\000\118\000\118\000\255\255\
    \255\255\125\000\255\255\255\255\255\255\255\255\118\000\128\000\
    \128\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\
    \128\000\125\000\125\000\125\000\125\000\125\000\125\000\125\000\
    \125\000\125\000\125\000\255\255\255\255\255\255\255\255\118\000\
    \255\255\255\255\255\255\118\000\255\255\255\255\255\255\255\255\
    \118\000\118\000\255\255\255\255\255\255\118\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\118\000\255\255\255\255\
    \255\255\118\000\255\255\118\000\255\255\118\000\255\255\118\000\
    \121\000\121\000\121\000\121\000\121\000\121\000\121\000\121\000\
    \121\000\121\000\255\255\255\255\255\255\125\000\255\255\255\255\
    \255\255\121\000\121\000\121\000\121\000\121\000\121\000\122\000\
    \122\000\122\000\122\000\122\000\122\000\122\000\122\000\122\000\
    \122\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \122\000\122\000\122\000\122\000\122\000\122\000\255\255\255\255\
    \255\255\121\000\121\000\121\000\121\000\121\000\121\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \122\000\122\000\122\000\122\000\122\000\122\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\125\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    ";
  Lexing.lex_base_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\001\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\007\000\
    \010\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_backtrk_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_default_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_trans_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\001\000\001\000\000\000\000\000\000\000\004\000\
    \004\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000";
  Lexing.lex_check_code = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\034\000\255\255\255\255\255\255\000\000\
    \034\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255";
  Lexing.lex_code = 
   "\255\001\255\255\002\255\255\000\002\255\000\001\255";
}

let rec token lexbuf =
  lexbuf.Lexing.lex_mem <- Array.make 3 (-1) ;   __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 267 "src/kernel_internals/parsing/logic_lexer.mll"
           ( token lexbuf )
# 886 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 268 "src/kernel_internals/parsing/logic_lexer.mll"
         ( update_newline_loc lexbuf; token lexbuf )
# 891 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 269 "src/kernel_internals/parsing/logic_lexer.mll"
                      ( update_newline_loc lexbuf; token lexbuf )
# 896 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 270 "src/kernel_internals/parsing/logic_lexer.mll"
                     ( token lexbuf )
# 901 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 272 "src/kernel_internals/parsing/logic_lexer.mll"
                       ( bs_identifier lexbuf )
# 906 "src/kernel_internals/parsing/logic_lexer.ml"

  | 5 ->
# 273 "src/kernel_internals/parsing/logic_lexer.mll"
                        ( let s = lexeme lexbuf in identifier s )
# 911 "src/kernel_internals/parsing/logic_lexer.ml"

  | 6 ->
# 275 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( CONSTANT (IntConstant (lexeme lexbuf)) )
# 916 "src/kernel_internals/parsing/logic_lexer.ml"

  | 7 ->
# 276 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( CONSTANT (IntConstant (lexeme lexbuf)) )
# 921 "src/kernel_internals/parsing/logic_lexer.ml"

  | 8 ->
# 277 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( CONSTANT (IntConstant (lexeme lexbuf)) )
# 926 "src/kernel_internals/parsing/logic_lexer.ml"

  | 9 ->
# 278 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( CONSTANT10 (lexeme lexbuf) )
# 931 "src/kernel_internals/parsing/logic_lexer.ml"

  | 10 ->
# 279 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( CONSTANT (IntConstant (lexeme lexbuf)) )
# 936 "src/kernel_internals/parsing/logic_lexer.ml"

  | 11 ->
let
# 280 "src/kernel_internals/parsing/logic_lexer.mll"
                 prelude
# 942 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 280 "src/kernel_internals/parsing/logic_lexer.mll"
                                                                   content
# 947 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) (lexbuf.Lexing.lex_curr_pos + -1) in
# 281 "src/kernel_internals/parsing/logic_lexer.mll"
      (
        let b = Buffer.create 5 in
        Buffer.add_string b prelude;
        let lbf = Lexing.from_string content in
        CONSTANT (IntConstant (chr b lbf ^ "'"))
      )
# 956 "src/kernel_internals/parsing/logic_lexer.ml"

  | 12 ->
# 294 "src/kernel_internals/parsing/logic_lexer.mll"
      ( CONSTANT (FloatConstant (lexeme lexbuf)) )
# 961 "src/kernel_internals/parsing/logic_lexer.ml"

  | 13 ->
let
# 297 "src/kernel_internals/parsing/logic_lexer.mll"
            n
# 967 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_curr_pos + -2) in
# 297 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( lexbuf.lex_curr_pos <- lexbuf.lex_curr_pos - 2;
                              CONSTANT (IntConstant n) )
# 972 "src/kernel_internals/parsing/logic_lexer.ml"

  | 14 ->
let
# 300 "src/kernel_internals/parsing/logic_lexer.mll"
                prelude
# 978 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 300 "src/kernel_internals/parsing/logic_lexer.mll"
                                                                content
# 983 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) (lexbuf.Lexing.lex_curr_pos + -1) in
# 301 "src/kernel_internals/parsing/logic_lexer.mll"
      ( STRING_LITERAL (prelude.[0] = 'L',content) )
# 987 "src/kernel_internals/parsing/logic_lexer.ml"

  | 15 ->
# 302 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( hash lexbuf )
# 992 "src/kernel_internals/parsing/logic_lexer.ml"

  | 16 ->
# 303 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( IMPLIES )
# 997 "src/kernel_internals/parsing/logic_lexer.ml"

  | 17 ->
# 304 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( IFF )
# 1002 "src/kernel_internals/parsing/logic_lexer.ml"

  | 18 ->
# 305 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( BIMPLIES )
# 1007 "src/kernel_internals/parsing/logic_lexer.ml"

  | 19 ->
# 306 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( BIFF )
# 1012 "src/kernel_internals/parsing/logic_lexer.ml"

  | 20 ->
# 307 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( AND )
# 1017 "src/kernel_internals/parsing/logic_lexer.ml"

  | 21 ->
# 308 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( OR )
# 1022 "src/kernel_internals/parsing/logic_lexer.ml"

  | 22 ->
# 309 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( NOT )
# 1027 "src/kernel_internals/parsing/logic_lexer.ml"

  | 23 ->
# 310 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOLLAR )
# 1032 "src/kernel_internals/parsing/logic_lexer.ml"

  | 24 ->
# 311 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( COMMA )
# 1037 "src/kernel_internals/parsing/logic_lexer.ml"

  | 25 ->
# 312 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( ARROW )
# 1042 "src/kernel_internals/parsing/logic_lexer.ml"

  | 26 ->
# 313 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Test state_stack; QUESTION )
# 1047 "src/kernel_internals/parsing/logic_lexer.ml"

  | 27 ->
# 314 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( SEMICOLON )
# 1052 "src/kernel_internals/parsing/logic_lexer.ml"

  | 28 ->
# 315 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( match get_state() with
                                  Normal  -> COLON
                                | Test -> pop_state(); COLON2
                            )
# 1060 "src/kernel_internals/parsing/logic_lexer.ml"

  | 29 ->
# 319 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( COLONCOLON )
# 1065 "src/kernel_internals/parsing/logic_lexer.ml"

  | 30 ->
# 320 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOT )
# 1070 "src/kernel_internals/parsing/logic_lexer.ml"

  | 31 ->
# 321 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOTDOT )
# 1075 "src/kernel_internals/parsing/logic_lexer.ml"

  | 32 ->
# 322 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOTDOTDOT )
# 1080 "src/kernel_internals/parsing/logic_lexer.ml"

  | 33 ->
# 323 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( MINUS )
# 1085 "src/kernel_internals/parsing/logic_lexer.ml"

  | 34 ->
# 324 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PLUS )
# 1090 "src/kernel_internals/parsing/logic_lexer.ml"

  | 35 ->
# 325 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( STAR )
# 1095 "src/kernel_internals/parsing/logic_lexer.ml"

  | 36 ->
# 326 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( AMP )
# 1100 "src/kernel_internals/parsing/logic_lexer.ml"

  | 37 ->
# 327 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( HATHAT )
# 1105 "src/kernel_internals/parsing/logic_lexer.ml"

  | 38 ->
# 328 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( HAT )
# 1110 "src/kernel_internals/parsing/logic_lexer.ml"

  | 39 ->
# 329 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PIPE )
# 1115 "src/kernel_internals/parsing/logic_lexer.ml"

  | 40 ->
# 330 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( TILDE )
# 1120 "src/kernel_internals/parsing/logic_lexer.ml"

  | 41 ->
# 331 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( SLASH )
# 1125 "src/kernel_internals/parsing/logic_lexer.ml"

  | 42 ->
# 332 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PERCENT )
# 1130 "src/kernel_internals/parsing/logic_lexer.ml"

  | 43 ->
# 333 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LT )
# 1135 "src/kernel_internals/parsing/logic_lexer.ml"

  | 44 ->
# 334 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GT )
# 1140 "src/kernel_internals/parsing/logic_lexer.ml"

  | 45 ->
# 335 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LE )
# 1145 "src/kernel_internals/parsing/logic_lexer.ml"

  | 46 ->
# 336 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GE )
# 1150 "src/kernel_internals/parsing/logic_lexer.ml"

  | 47 ->
# 337 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EQ )
# 1155 "src/kernel_internals/parsing/logic_lexer.ml"

  | 48 ->
# 338 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EQUAL )
# 1160 "src/kernel_internals/parsing/logic_lexer.ml"

  | 49 ->
# 339 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( NE )
# 1165 "src/kernel_internals/parsing/logic_lexer.ml"

  | 50 ->
# 340 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LPAR )
# 1170 "src/kernel_internals/parsing/logic_lexer.ml"

  | 51 ->
# 341 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RPAR )
# 1175 "src/kernel_internals/parsing/logic_lexer.ml"

  | 52 ->
# 342 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LBRACE )
# 1180 "src/kernel_internals/parsing/logic_lexer.ml"

  | 53 ->
# 343 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RBRACE )
# 1185 "src/kernel_internals/parsing/logic_lexer.ml"

  | 54 ->
# 344 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LSQUARE )
# 1190 "src/kernel_internals/parsing/logic_lexer.ml"

  | 55 ->
# 345 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RSQUARE )
# 1195 "src/kernel_internals/parsing/logic_lexer.ml"

  | 56 ->
# 346 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LTCOLON )
# 1200 "src/kernel_internals/parsing/logic_lexer.ml"

  | 57 ->
# 347 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( COLONGT )
# 1205 "src/kernel_internals/parsing/logic_lexer.ml"

  | 58 ->
# 348 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LTLT )
# 1210 "src/kernel_internals/parsing/logic_lexer.ml"

  | 59 ->
# 349 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GTGT )
# 1215 "src/kernel_internals/parsing/logic_lexer.ml"

  | 60 ->
let
# 350 "src/kernel_internals/parsing/logic_lexer.mll"
                 c
# 1221 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 350 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( find_utf8 c )
# 1225 "src/kernel_internals/parsing/logic_lexer.ml"

  | 61 ->
# 351 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EOF )
# 1230 "src/kernel_internals/parsing/logic_lexer.ml"

  | 62 ->
# 352 "src/kernel_internals/parsing/logic_lexer.mll"
        ( lex_error lexbuf ("illegal character " ^ lexeme lexbuf) )
# 1235 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_token_rec lexbuf __ocaml_lex_state

and chr buffer lexbuf =
    __ocaml_lex_chr_rec buffer lexbuf 115
and __ocaml_lex_chr_rec buffer lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 356 "src/kernel_internals/parsing/logic_lexer.mll"
      ( let s = lexeme lexbuf in
        let real_s = String.sub s 2 (String.length s - 2) in
        let rec add_one_char s =
          let l = String.length s in
          if l = 0 then ()
          else
          let h = int_of_digit s.[0] in
          let c,s =
            if l = 1 then (h,"")
            else
              (16*h + int_of_digit s.[1],
               String.sub s 2 (String.length s - 2))
          in
          Buffer.add_char buffer (Char.chr c); add_one_char s
        in add_one_char real_s; chr buffer lexbuf
      )
# 1262 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 373 "src/kernel_internals/parsing/logic_lexer.mll"
      ( let s = lexeme lexbuf in
        let real_s = String.sub s 1 (String.length s - 1) in
        let rec value i s =
          if s = "" then i
          else value (8*i+int_of_digit s.[0])
            (String.sub s 1 (String.length s -1))
        in let c = value 0 real_s in
        Buffer.add_char buffer (Char.chr c); chr buffer lexbuf
      )
# 1275 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 383 "src/kernel_internals/parsing/logic_lexer.mll"
      ( Buffer.add_char buffer
          (match (lexeme lexbuf).[1] with
               'a' -> '\007'
             | 'b' -> '\b'
             | 'f' -> '\012'
             | 'n' -> '\n'
             | 'r' -> '\r'
             | 't' -> '\t'
             | '\'' -> '\''
             | '"' -> '"'
             | '?' -> '?'
             | '\\' -> '\\'
             | _ -> assert false
          ); chr buffer lexbuf)
# 1293 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 397 "src/kernel_internals/parsing/logic_lexer.mll"
        ( Buffer.contents buffer )
# 1298 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 398 "src/kernel_internals/parsing/logic_lexer.mll"
       ( Buffer.add_string buffer (lexeme lexbuf); chr buffer lexbuf )
# 1303 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_chr_rec buffer lexbuf __ocaml_lex_state

and hash lexbuf =
    __ocaml_lex_hash_rec lexbuf 125
and __ocaml_lex_hash_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 401 "src/kernel_internals/parsing/logic_lexer.mll"
        ( update_newline_loc lexbuf; token lexbuf)
# 1315 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 402 "src/kernel_internals/parsing/logic_lexer.mll"
             ( hash lexbuf)
# 1320 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 403 "src/kernel_internals/parsing/logic_lexer.mll"
              ( (* We are seeing a line number. This is the number for the
                   * next line *)
                 let s = Lexing.lexeme lexbuf in
                 let lineno = try
                   int_of_string s
                 with Failure ("int_of_string") ->
                   (* the int is too big. *)
                   Kernel.warning ~source:lexbuf.lex_start_p
                     "Bad line number in preprocessed file: %s"  s;
                   (-1)
                 in
                 update_line_loc lexbuf (lineno - 1) true 0;
                  (* A file name may follow *)
		  file lexbuf )
# 1338 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 417 "src/kernel_internals/parsing/logic_lexer.mll"
                ( hash lexbuf )
# 1343 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 418 "src/kernel_internals/parsing/logic_lexer.mll"
            ( endline lexbuf)
# 1348 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_hash_rec lexbuf __ocaml_lex_state

and file lexbuf =
    __ocaml_lex_file_rec lexbuf 134
and __ocaml_lex_file_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 421 "src/kernel_internals/parsing/logic_lexer.mll"
                      ( update_newline_loc lexbuf; token lexbuf)
# 1360 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 422 "src/kernel_internals/parsing/logic_lexer.mll"
                  ( file lexbuf)
# 1365 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 424 "src/kernel_internals/parsing/logic_lexer.mll"
            (
              let n = Lexing.lexeme lexbuf in
              let n1 = String.sub n 1
                ((String.length n) - 2) in
              update_file_loc lexbuf n1;
	      endline lexbuf
            )
# 1376 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 432 "src/kernel_internals/parsing/logic_lexer.mll"
      ( endline lexbuf)
# 1381 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_file_rec lexbuf __ocaml_lex_state

and endline lexbuf =
    __ocaml_lex_endline_rec lexbuf 141
and __ocaml_lex_endline_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 435 "src/kernel_internals/parsing/logic_lexer.mll"
                ( update_newline_loc lexbuf; token lexbuf)
# 1393 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 436 "src/kernel_internals/parsing/logic_lexer.mll"
                                ( EOF )
# 1398 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 437 "src/kernel_internals/parsing/logic_lexer.mll"
      ( endline lexbuf)
# 1403 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_endline_rec lexbuf __ocaml_lex_state

;;

# 439 "src/kernel_internals/parsing/logic_lexer.mll"
 
  let copy_lexbuf dest_lexbuf src_loc =
    update_file_loc dest_lexbuf src_loc.pos_fname;
    update_line_loc dest_lexbuf src_loc.pos_lnum true 0;
    let bol = src_loc.Lexing.pos_cnum - src_loc.Lexing.pos_bol in
    update_bol_loc dest_lexbuf (-bol)

  let parse_from_location f (loc, s : Lexing.position * string) =
    let output = 
      if Kernel.ContinueOnAnnotError.get() then Kernel.warning ~once:true
      else Kernel.error ~once:false
    in
    let lb = from_string s in
    copy_lexbuf lb loc;
    try
      let res = f token lb in
      lb.Lexing.lex_curr_p, res
    with
      | Failure _ (* raised by the lexer itself, through [f] *)
      | Parsing.Parse_error ->
        output
	  ~source:lb.lex_curr_p
          "unexpected token '%s'" (Lexing.lexeme lb);
        Logic_utils.exit_kw_c_mode ();
        raise Parsing.Parse_error
      | Error (_, m) ->
        output ~source:lb.lex_curr_p "%s" m;
        Logic_utils.exit_kw_c_mode ();
        raise Parsing.Parse_error
      | Logic_utils.Not_well_formed (loc, m) ->
        output ~source:(fst loc) "%s" m;
        Logic_utils.exit_kw_c_mode ();
        raise Parsing.Parse_error
      | exn ->
        Kernel.fatal ~source:lb.lex_curr_p "Unknown error (%s)"
          (Printexc.to_string exn)

  let lexpr = parse_from_location Logic_parser.lexpr_eof

  let annot = parse_from_location Logic_parser.annot

  let spec = parse_from_location Logic_parser.spec

  (* ACSL extension for external spec file *)
  let ext_spec = parse_from_location Logic_parser.ext_spec

  type 'a parse = Lexing.position * string -> Lexing.position * 'a

  let chr lexbuf =
    let buf = Buffer.create 16 in
    chr buf lexbuf

# 1463 "src/kernel_internals/parsing/logic_lexer.ml"
